#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Wed Apr  3 15:50:59 2019

File containing object parameterizations for PtychoKeras

@author: Jacob Seifert, j.seifert@uu.nl
"""

# =============================================================================
# import functions
# =============================================================================


import numpy as np
import matplotlib.pyplot as plt
from scipy.ndimage import rotate

# =============================================================================
# parameterizations
# =============================================================================

def param_of_TH(x0, y0, w, Tw, Hw, Hh, d, alpha, x_dim=1038, y_dim=1388):
    """ Returns a (complex) TH object given a set of parameters.
        Lengths in pixel units.
    """

    # initializations
    img_imaginary = np.zeros((x_dim, y_dim))
    img_real = np.zeros((x_dim, y_dim))
    TH = np.zeros((Hh, Tw + d + Hw))

    # Draw the lines
    TH[0:w, 0:Tw] = 1
    TH[0:Hh, (Tw-w)//2:(Tw+w)//2] = 1
    TH[0:Hh, Tw+d:Tw+d+w] = 1
    TH[0:Hh, Tw+d+Hw-w:Tw+d+Hw] = 1
    TH[(Hh-w)//2:(Hh+w)//2, Tw+d:Tw+d+Hw] = 1
    TH = rotate(TH, alpha)

    # stitch TH and total image together
    img_real[(x_dim-TH.shape[0]+x0)//2:(x_dim+TH.shape[0]+x0)//2,
             (y_dim-TH.shape[1]+y0)//2:(y_dim+TH.shape[1]+y0)//2] += TH
    return img_real + 1j * img_imaginary


# =============================================================================
# Testing ground
# =============================================================================

x0 = 300
y0 = -400
w = 50
Tw = 300
Hw = 350
Hh = 300
d = 50
alpha = 15
x_dim=1038
y_dim=1388
TH = param_of_TH(x0, y0, w, Tw, Hw, Hh, d, alpha, x_dim=1038, y_dim=1388)

plt.imshow(np.abs(TH))
plt.colorbar()
plt.show()



# EOF